#version 150 core

struct LightProperties
{
	vec3 direction;
	vec4 ambientColor;
	vec4 diffuseColor;
	vec4 specularColor;
};

struct MaterialProperties
{
	vec4 ambientColor;
	vec4 diffuseColor;
	vec4 specularColor;
	float specularExponent;
};


uniform mat4 projectionMatrix;
uniform mat4 modelMatrix;
uniform mat4 viewMatrix;
uniform mat3 normalMatrix;

uniform	LightProperties light;
uniform MaterialProperties material;

uniform sampler2D colorTexture;
uniform sampler2D nightTexture;

in vec4 in_position;
in vec3 in_normal;
in vec2 in_texCoord;
out vec3 ex_color;
out vec2 texCoordout;
out float diffuseFactor;

void main(void)
{
		vec4 vert =  modelMatrix * in_position;
		vec3 norm = normalize(normalMatrix * in_normal);
		float diffuse = dot(norm, -normalize(light.direction));
		ex_color = vec3(1.0, 1.0, 1.0) * vec3(light.diffuseColor * light.ambientColor* material.diffuseColor) * max(diffuse, 0.1);
		gl_Position = projectionMatrix * viewMatrix * vert;
		texCoordout = in_texCoord;
		diffuseFactor = diffuse;
	
}
